Blaeu, creating measurements on RIPE Atlas probes
=================================================

This is a set of [Python](https://www.python.org/) programs to start distributed Internet measurements on the network of [RIPE Atlas probes](https://atlas.ripe.net/).

For installation and examples, see [my article at RIPE Labs](https://labs.ripe.net/Members/stephane_bortzmeyer/using-ripe-atlas-to-debug-network-connectivity-problems).

Blaeu requires Python 3.

Note that [the old version](https://github.com/RIPE-Atlas-Community/ripe-atlas-community-contrib) ran on Python 2 but is no longer maintained.

Reference site
--------------

[On FramaGit](https://framagit.org/bortzmeyer/blaeu)

Author
------

Stéphane Bortzmeyer <stephane+frama@bortzmeyer.org>

